@@ -1,9 +1,9 @@
 package Dist::Zilla::Plugin::WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-01'; # DATE
+our $DATE = '2020-05-04'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-WordList'; # DIST
-our $VERSION = '0.056'; # VERSION
+our $VERSION = '0.057'; # VERSION
 
 use 5.014;
 use strict;
@@ -42,8 +42,13 @@ sub munge_files {
         my $content = $file->content;
 
         # Add statistics to %STATS variable
+      CREATE_STATS:
         {
             require $package_pm;
+            no strict 'refs';
+            my $param_spec = \%{"$package\::PARAMS"};
+            last CREATE_STATS if keys %$param_spec;
+
             my $wl = $package->new;
 
             my $total_len = 0;
@@ -116,7 +121,7 @@ Dist::Zilla::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.056 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2020-05-01.
+This document describes version 0.057 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2020-05-04.
 
 =head1 SYNOPSIS
 
